@@ -8,7 +8,7 @@ debug_opts="-O2"
 def_opts=
 largefile_opts="-D_FILE_OFFSET_BITS=64 -D_LARGEFILE_SOURCE=1"
 fifo_opts=""
-libvers="-DCdrskin_libburn_1_0_2"
+libvers="-DCdrskin_libburn_1_0_4"
 
 # To be used if Makefile.am uses libburn_libburn_la_CFLAGS
 # burn="libburn/libburn_libburn_la-"
@@ -47,15 +47,15 @@ do
     libdax_audioxtr_o=
     libdax_msgs_o="$burn"message.o
     cleanup_src_or_obj="-DCleanup_has_no_libburn_os_H cdrskin/cleanup.c"
-  elif test "$i" = "-libburn_1_0_2"
+  elif test "$i" = "-libburn_1_0_4"
   then
-    libvers="-DCdrskin_libburn_1_0_2"
+    libvers="-DCdrskin_libburn_1_0_4"
     libdax_audioxtr_o="$burn"libdax_audioxtr.o
     libdax_msgs_o="$burn"libdax_msgs.o
     cleanup_src_or_obj="$burn"cleanup.o
   elif test "$i" = "-libburn_svn"
   then
-    libvers="-DCdrskin_libburn_1_0_3"
+    libvers="-DCdrskin_libburn_1_0_5"
     libdax_audioxtr_o="$burn"libdax_audioxtr.o
     libdax_msgs_o="$burn"libdax_msgs.o
     cleanup_src_or_obj="$burn"cleanup.o
@@ -109,7 +109,7 @@ do
     echo "Options:"
     echo "  -compile_cdrfifo  compile program cdrskin/cdrfifo."
     echo "  -compile_dewav    compile program test/dewav without libburn."
-    echo "  -libburn_1_0_2    set macro to match libburn-1.0.2"
+    echo "  -libburn_1.0.4    set macro to match libburn-1.0.4"
     echo "  -libburn_svn      set macro to match current libburn-SVN."
     echo "  -dvd_obs_64k      64 KB default size for DVD/BD writing."
     echo "  -use_libcdio      link with -lcdio because libburn uses it."
